@@ -32,7 +32,6 @@ import csv
 import datetime
 import threading
 import numpy as np
-import pandas as pd
 import xlrd
 import os
 from openpyxl import Workbook
@@ -44,21 +43,16 @@ from django.contrib import admin
 from django.contrib import messages
 from django.utils.http import urlquote
 
-from .. import get_model_max_id_in_db
 from .. import reset_db_sequence
 from ..pure import remove_temp_file
 
-import shutil
 # --- 初始化环境 ---
 from .admin_env_init import CHANGE_LIST_HTML_PATH, TEMPDIR, BD_USE_GUARDIAN, CHANGE_FORM_TEMPLATE, BD_USE_SIMPLEUI
 from .admin_env_init import BD_USE_AJAX_ADMIN
 from tqdm import tqdm
 from pandas._libs.tslibs.timestamps import Timestamp
-from bddjango import get_base_model, get_model_max_id_in_db, old_get_model_max_id_in_db
+from bddjango import get_base_model, get_model_max_id_in_db
 from django.contrib.admin.helpers import ACTION_CHECKBOX_NAME
-import datetime as dt
-from bdtime import tt
-import time
 import pandas as pd
 from django.contrib.auth import get_permission_codename
 import re
@@ -67,6 +61,7 @@ import html
 
 IAdmin = admin.ModelAdmin
 
+
 if BD_USE_SIMPLEUI and BD_USE_AJAX_ADMIN:
     from simpleui.admin import AjaxAdmin
 
@@ -724,12 +719,22 @@ class BaseAdmin(ForceRunActionsAdmin):
     orm_executor = True     # 使用orm过滤器
 
     _ajax_search_term = None        # 用来ajax过滤
+    _ajax_return_qs_ls = None       # 以便使用ajax方法返回的qs_ls
 
     def get_search_results(self, request, queryset, search_term):
         if not self.orm_executor:
             ret = super().get_search_results(request, queryset, search_term)
             return ret
 
+        # --- 根据ajax方法返回qs_ls
+        bd_ajax_return_qs_ls = '_ajax_return_qs_ls'
+        if hasattr(self, bd_ajax_return_qs_ls) and getattr(self, bd_ajax_return_qs_ls) is not None:
+            queryset = getattr(self, bd_ajax_return_qs_ls)
+            setattr(self, bd_ajax_return_qs_ls, None)
+            ret = (queryset, False)
+            return ret
+
+        # --- 根据orm语句进行过滤
         prefix = '~'  # 反向过滤~pk
 
         reg = re.compile(r'^\..*?[\)\]]$')  # 让.filter(xxx), .order_by(xxx)等orm语句可以执行
